<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

$wp_customize->add_section( 'elead_pro_team', array(
	'title'             => esc_html__( 'Team','elead-pro' ),
	'description'       => esc_html__( 'Team Section Options.', 'elead-pro' ),
	'panel'             => 'elead_pro_sections_panel',
) );

// team section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[team_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['team_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[team_enable]', array(
	'label'            	=> esc_html__( 'Enable Team Section', 'elead-pro' ),
	'section'          	=> 'elead_pro_team',
	'type'             	=> 'checkbox',
) );

// team section title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[team_section_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['team_section_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[team_section_title]', array(
	'label'            	=> esc_html__( 'Section Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_team',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_team_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[team_section_title]', array(
		'selector'            => '#team-members .entry-header h1.entry-title',
		'settings'            => 'elead_pro_theme_options[team_section_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_team_title',
    ) );
}

// team section subtitle setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[team_section_subtitle]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['team_section_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[team_section_subtitle]', array(
	'label'            	=> esc_html__( 'Section SubTitle', 'elead-pro' ),
	'section'          	=> 'elead_pro_team',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_team_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[team_section_subtitle]', array(
		'selector'            => '#team-members .entry-header p.entry-title-desc',
		'settings'            => 'elead_pro_theme_options[team_section_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_team_subtitle',
    ) );
}

// team section excerpt setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[team_section_excerpt]', array(
	'sanitize_callback'	=> 'wp_kses_post',
	'default'          	=> $options['team_section_excerpt'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[team_section_excerpt]', array(
	'label'            	=> esc_html__( 'Section Description', 'elead-pro' ),
	'section'          	=> 'elead_pro_team',
	'type'             	=> 'textarea',
	'active_callback'	=> 'elead_pro_is_team_enable',
) );

// team post hr setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[team_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[team_hr]',
	array(
		'section'         => 'elead_pro_team',
		'active_callback' => 'elead_pro_is_team_enable',
		'type'			  => 'hr'
) ) );

// team section content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
) );

$wp_customize->add_control( 'elead_pro_theme_options[team_content_type]', array(
	'label'            	=> esc_html__( 'Team Content Type', 'elead-pro' ),
	'section'          	=> 'elead_pro_team',
	'type'             	=> 'select',
	'active_callback'	=> 'elead_pro_is_team_enable',
	'choices'			=> elead_pro_team_content_type(),
) );

// team section content type category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'elead_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[team_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Four latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_team',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_team_content_category',
) ) );

// team section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[team_content_post]', array(
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[team_content_post]', array(
	'active_callback'	=> 'elead_pro_team_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 4. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_team',
	'type'				=> 'text'
) );

// team section content type team setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[team_content_team]', array(
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[team_content_team]', array(
	'active_callback'	=> 'elead_pro_team_content_team',
	'label'             => esc_html__( 'Input Team Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of teams allowed is 4. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_team',
	'type'				=> 'text'
) );

// team section content type team category setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[team_content_team_category]', array(
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[team_content_team_category]', array(
	'label'           => esc_html__( 'Select Team Category', 'elead-pro' ),
	'description'     => esc_html__( 'Four latest teams from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_team',
	'taxonomy'        => 'tp-team-category',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_team_content_team_category',
) ) );


for ( $i = 1; $i <= 4; $i++ ) {
	// Team custom post hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[team_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[team_custom_hr_line_'.$i.']',
		array(
			'section'         => 'elead_pro_team',
			'active_callback' => 'elead_pro_team_content_custom',
			'type'			  => 'hr'
	) ) );

	// Team custom note
	$wp_customize->add_setting( 'elead_pro_theme_options[team_custom_note_'.$i.']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[team_custom_note_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Input Custom Value For Team %s ', 'elead-pro' ),$i ),
		'section'         	=> 'elead_pro_team',
		'type'            	=> 'description',
		'active_callback' 	=> 'elead_pro_team_content_custom',
	) ) );

	// team section custom title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[team_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( 'Ricky Ortega','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[team_custom_title_'.$i.']', array(
		'active_callback'	=> 'elead_pro_team_content_custom',
		'label'             => sprintf( esc_html__( 'Team Member Name %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_team',
		'type'				=> 'text'
	) );

	// team section custom subtitle setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[team_custom_subtitle_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( 'Art Teacher','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[team_custom_subtitle_'.$i.']', array(
		'active_callback'	=> 'elead_pro_team_content_custom',
		'label'             => sprintf( esc_html__( 'Team Member Designation %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_team',
		'type'				=> 'text'
	) );

	// team section custom background image setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[team_custom_image_'.$i.']', array(
		'sanitize_callback' => 'elead_pro_sanitize_image',
		'default'			=> get_template_directory_uri() . '/assets/uploads/professional-01.jpg',
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'elead_pro_theme_options[team_custom_image_'.$i.']',
			array(
			'label'       		=> sprintf( esc_html__( 'Team Member Image %s', 'elead-pro' ),$i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'elead-pro' ), 400, 400 ),
			'section'     		=> 'elead_pro_team',
			'active_callback'	=> 'elead_pro_team_content_custom',
	) ) );
	
	// team section custom title link setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[team_member_custom_url_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( '#','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[team_member_custom_url_'.$i.']', array(
		'active_callback'	=> 'elead_pro_team_content_custom',
		'label'             => sprintf( esc_html__( 'Team Member Single Link %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_team',
		'type'				=> 'text'
	) );

}

// team section button label setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[team_custom_btn_label]', array(
	'default'           => $options['team_custom_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[team_custom_btn_label]', array(
	'active_callback'	=> 'elead_pro_team_content_category_disable',
	'label'             => esc_html__( 'Custom button label', 'elead-pro' ),
	'section'           => 'elead_pro_team',
	'type'				=> 'text'
) );

// team section button label url setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[team_custom_btn_url]', array(
	'default'           => $options['team_custom_btn_url'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[team_custom_btn_url]', array(
	'active_callback'	=> 'elead_pro_team_content_category_disable',
	'label'             => esc_html__( 'Custom button url', 'elead-pro' ),
	'section'           => 'elead_pro_team',
	'type'				=> 'text'
) );