<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

$wp_customize->add_section( 'elead_pro_testimonial', array(
	'title'             => esc_html__( 'Testimonial','elead-pro' ),
	'description'       => esc_html__( 'Testimonial Section Options.', 'elead-pro' ),
	'panel'             => 'elead_pro_sections_panel',
) );

// testimonial Section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['testimonial_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[testimonial_enable]', array(
	'label'            	=> esc_html__( 'Enable Testimonial Section', 'elead-pro' ),
	'section'          	=> 'elead_pro_testimonial',
	'type'             	=> 'checkbox',
) );

// testimonial Section title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[testimonial_title]', array(
	'label'            	=> esc_html__( 'Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_testimonial',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_testimonial_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[testimonial_title]', array(
		'selector'            => '#testoiioail .wrapper .hentry .entry-header h2.entry-title',
		'settings'            => 'elead_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_testimonial_title',
    ) );
}

// testimonial Section subtitle setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['testimonial_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[testimonial_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_testimonial',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_testimonial_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[testimonial_sub_title]', array(
		'selector'            => '#testimonial .wrapper .hentry .entry-header p.entry-title-desc',
		'settings'            => 'elead_pro_theme_options[testimonial_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_testimonial_sub_title',
    ) );
}

// testimonial Section content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
) );

$wp_customize->add_control( 'elead_pro_theme_options[testimonial_content_type]', array(
	'label'            	=> esc_html__( 'Testimonial Content Type', 'elead-pro' ),
	'section'          	=> 'elead_pro_testimonial',
	'type'             	=> 'select',
	'active_callback'	=> 'elead_pro_is_testimonial_enable',
	'choices'			=> elead_pro_testimonial_content_type(),
) );

// Add testimonial count setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[no_of_testimonial]', array(
	'default'           => $options['no_of_testimonial'],
	'sanitize_callback' => 'elead_pro_sanitize_number_range',
	'validate_callback' => 'elead_pro_validate_testimonial_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[no_of_testimonial]', array(
	'label'           	=> esc_html__( 'Number of testimonial', 'elead-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'elead-pro' ),
	'section'         	=> 'elead_pro_testimonial',
	'type'            	=> 'number',
	'active_callback' 	=> 'elead_pro_testimonial_content_count',
	'input_attrs'     	=> array(
		'max' 	=> 6,
		'min' 	=> 3,
		'style' => 'width:100px'
	)
) );

// testimonial Section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_content_post]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[testimonial_content_post]', array(
	'active_callback'	=> 'elead_pro_testimonial_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 6. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_testimonial',
	'type'				=> 'text',
) );

// testimonial Section content type category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'elead_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[testimonial_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_testimonial',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_testimonial_content_category',
) ) );

// testimonial Section content type testimonial setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_content_testimonial]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[testimonial_content_testimonial]', array(
	'active_callback'	=> 'elead_pro_testimonial_content_testimonial',
	'label'             => esc_html__( 'Input Testimonial Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 6. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_testimonial',
	'type'				=> 'text',
) );

// testimonial section content type recent testimonial setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_content_recent_testimonial]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[testimonial_content_recent_testimonial]', array(
	'label'       => esc_html__( 'Latest Testimonial will be shown.', 'elead-pro' ),
	'section'         	=> 'elead_pro_testimonial',
	'type'            	=> 'description',
	'active_callback' 	=> 'elead_pro_testimonial_content_recent',
) ) );


for ( $i = 1; $i <= $options['no_of_testimonial']; $i++ ) {


	// Testimonial custom post hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[testimonial_custom_hr_line_'.$i.']',
		array(
			'section'         => 'elead_pro_testimonial',
			'active_callback' => 'elead_pro_testimonial_content_custom',
			'type'			  => 'hr'
	) ) );

	// Testimonial custom note
	$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_custom_note_'.$i.']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[testimonial_custom_note_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Input Custom Value For Testimonial %s ', 'elead-pro' ),$i ),
		'section'         	=> 'elead_pro_testimonial',
		'type'            	=> 'description',
		'active_callback' 	=> 'elead_pro_testimonial_content_custom',
	) ) );

	// Testimonial Section custom title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( 'Sia Ortega','elead-pro'),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[testimonial_custom_title_'.$i.']', array(
		'active_callback'	=> 'elead_pro_testimonial_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Title %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_testimonial',
		'type'				=> 'text'
	) );

	// Testimonial Section custom title link setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_custom_btn_url_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( '#','elead-pro'),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[testimonial_custom_btn_url_'.$i.']', array(
		'active_callback'	=> 'elead_pro_testimonial_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Link %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_testimonial',
		'type'				=> 'text'
	) );

	// Testimonial Section custom position setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_custom_position_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( 'Ex Student','elead-pro'),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[testimonial_custom_position_'.$i.']', array(
		'active_callback'	=> 'elead_pro_testimonial_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Designation %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_testimonial',
		'type'				=> 'text'
	) );

	// Testimonial Section custom excerpt setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_custom_excerpt_'.$i.']', array(
		'sanitize_callback' => 'wp_kses_post',
		'default'			=> esc_html__( 'Suspendisse semper nulla et orci laoreet, eget sodales dui porttitor. Sed et laoreet lectus. Donec eget eros sit amet dui dignissim lobortis eu ut risus. Vivamus maximus neque nunc, sit amet sodales lectus tempus id.','elead-pro'),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[testimonial_custom_excerpt_'.$i.']', array(
		'active_callback'	=> 'elead_pro_testimonial_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Statement %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_testimonial',
		'type'				=> 'textarea'
	) );

	// Testimonial Section background image setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[testimonial_custom_image_'.$i.']', array(
		'sanitize_callback' => 'elead_pro_sanitize_image',
		'default'			=> get_template_directory_uri() . '/assets/uploads/testimonial-02.jpg',
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'elead_pro_theme_options[testimonial_custom_image_'.$i.']',
			array(
			'label'       		=> sprintf( esc_html__( 'Custom Image %s', 'elead-pro' ),$i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'elead-pro' ), 150, 150 ),
			'section'     		=> 'elead_pro_testimonial',
			'active_callback'	=> 'elead_pro_testimonial_content_custom',
	) ) );
}