<?php
/**
 * Blog page options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

$wp_customize->add_section( 'elead_pro_blog', array(
	'title'            		=> esc_html__( 'Blog Page Options','elead-pro' ),
	'description'      		=> esc_html__( 'Blog Page Options.', 'elead-pro' ),
	'panel'            		=> 'elead_pro_theme_options_panel',
) );

// service Section title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[blog_section_title]', array(
	'default'           => $options['blog_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[blog_section_title]', array(
	'label'             => esc_html__( 'Blog Title', 'elead-pro' ),
	'description'      	=> esc_html__( 'Input Place For Title.', 'elead-pro' ),
	'section'           => 'elead_pro_blog',
	'type'				=> 'text'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[blog_section_title]', array(
		'selector'            => '.wrapper .entry-header h2.section-title',
		'settings'            => 'elead_pro_theme_options[blog_section_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_blog_title',
    ) );
}

//service Section subtitle setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[blog_section_subtitle]', array(
	'default'           => $options['blog_section_subtitle'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[blog_section_subtitle]', array(
	'label'             => esc_html__( 'Blog SubTitle', 'elead-pro' ),
	'description'      	=> esc_html__( 'Input Place For Subtitle.', 'elead-pro' ),
	'section'           => 'elead_pro_blog',
	'type'				=> 'text'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[blog_section_subtitle]', array(
		'selector'            => '.wrapper .entry-header p.entry-title-desc',
		'settings'            => 'elead_pro_theme_options[blog_section_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_blog_sub_title',
    ) );
}


// Read more text.
$wp_customize->add_setting( 'elead_pro_theme_options[read_more_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			  => $options['read_more_text'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[read_more_text]', array(
	'label'       => esc_html__( 'Read More Text', 'elead-pro' ),
	'section'     => 'elead_pro_blog',
	'type'        => 'text',
) );


// blog date enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[enable_blog_date]', array(
	'sanitize_callback'		=> 'elead_pro_sanitize_checkbox',
	'default'             	=> $options['enable_blog_date'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[enable_blog_date]', array(
	'label'               	=> esc_html__( 'Enable Date', 'elead-pro' ),
	'section'             	=> 'elead_pro_blog',
	'type'                	=> 'checkbox',
) );

// category enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[category_enable]', array(
	'sanitize_callback'		=> 'elead_pro_sanitize_checkbox',
	'default'             	=> $options['category_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[category_enable]', array(
	'label'               	=> esc_html__( 'Enable Category', 'elead-pro' ),
	'section'             	=> 'elead_pro_blog',
	'type'                	=> 'checkbox',
) );

// exclude category from blog category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[blog_exclude_categories]', array(
	'sanitize_callback' => 'elead_pro_sanitize_category_list'
) );

$wp_customize->add_control( new Elead_Pro_Multiple_Category_Control( $wp_customize, 'elead_pro_theme_options[blog_exclude_categories]', array(
	'label'           => esc_html__( 'Select Categories to Exclude', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_blog',
	'type'			  => 'select-multiple-category',
) ) );