<?php 
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_about_section() {
        $options = elead_pro_get_theme_options();

        // Check if about is enabled
        $enable_about = apply_filters( 'elead_pro_section_status', true, 'about_enable' );

        if ( true !== $enable_about ) {
            return false;
        }

        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_about_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render about section now.
        elead_pro_render_about_section( $section_details );
    }
endif;
add_action( 'elead_pro_primary_content_action', 'elead_pro_add_about_section', 20 );


if ( ! function_exists( 'elead_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Elead Pro 1.0
    * @param array $input about section details.
    */
    function elead_pro_get_about_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // about type
        $about_content_type  = $options['about_content_type'];

        $content = array();
        switch ( $about_content_type ) {
          	case 'demo':
                $content[0]['title']    = esc_html__( 'About Us', 'elead-pro' );
                $content[0]['trim_excerpt']  = esc_html__( 'Proin urna nisl, egestas eget varius vel, commodo mattis elit. Nulla dapibus leo in nisi porttitor, sed dapibus risus porta. Etiam id aliquam massa. Fusce dignissim ex sollicitudin, consequat odio a, rhoncus massa. Vivamus venenatis pulvinar cursus habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.', 'elead-pro' );
                $content[0]['url']      = '#';
            break;        

            case 'custom':
                $content[0]['title']    = ! empty( $options['about_custom_title'] ) ? $options['about_custom_title'] : esc_html__( 'About Us', 'elead-pro' );
                $content[0]['trim_excerpt']  = ! empty( $options['about_custom_excerpt'] ) ? $options['about_custom_excerpt'] : '';
                $content[0]['url']      = ! empty( $options['about_custom_url'] ) ? $options['about_custom_url'] : '';
                                            
            break;

            case 'post':
                $post_id = '';
                
                if ( ! empty( $options['about_content_post'] ) )
                    $post_id = absint( $options['about_content_post'] );

                // Bail if no valid pages are selected.
                if ( empty( $post_id ) ) {
                    return $input;
                }

                $img_array = null;
                if ( has_post_thumbnail( $post_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                }
                if ( isset( $img_array ) ) {
                    $content[0]['img_array'] = $img_array;
                }
                $content[0]['title']    = get_the_title( $post_id );
                $content[0]['url']      = get_the_permalink( $post_id );
                $content[0]['excerpt']  = get_post_field( 'post_content', $post_id );
                $content[0]['trim_excerpt']  = elead_pro_trim_content( 50, get_post( $post_id ) );
                                            
          	break;

            case 'page':
                $page_id = '';
                
                if ( ! empty( $options['about_content_page'] ) )
                    $page_id = absint( $options['about_content_page'] );

                // Bail if no valid pages are selected.
                if ( empty( $page_id ) ) {
                    return $input;
                }

                $img_array = null;
                if ( has_post_thumbnail( $page_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'full' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                }
                if ( isset( $img_array ) ) {
                    $content[0]['img_array'] = $img_array;
                }
                $content[0]['title']    = get_the_title( $page_id );
                $content[0]['url']      = get_the_permalink( $page_id );
                $content[0]['excerpt']  = get_post_field( 'post_content', $page_id );
                $content[0]['trim_excerpt']  = elead_pro_trim_content( 50, get_post( $page_id ) );
                                            
            break;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'elead_pro_filter_about_section_details', 'elead_pro_get_about_section_details' );

/**
 * Start about section
 *
 * @return string about multiple image
 * @since Elead Pro 1.0
 *
*/
function elead_pro_catch_that_image( $content_details ) {
    $about_multiple_img = '';
    ob_start();
    ob_end_clean();
    $output = preg_match_all('/src="([^"]*)"/', $content_details, $matches);
    $about_multiple_img = $matches[1];

    if( empty( $about_multiple_img ) ) {
        for( $i=1; $i<=3; $i++ ) {
            $about_multiple_img[$i] = get_template_directory_uri() . '/assets/uploads/no-featured-image-500x500.jpg';
        } 
    }
    return $about_multiple_img;
}

if ( ! function_exists( 'elead_pro_render_about_section' ) ) :
    /**
    * Start about section
    *
    * @return string about content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_about_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        $about_content_type  = $options['about_content_type'];
        $about_image_type  = $options['about_image_type'];
        $about_subtitle  = ! empty( $options['about_custom_subtitle'] ) ? $options['about_custom_subtitle'] : '';
        $readmore   = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read More', 'elead-pro' );

        $about_multiple_image = array();
        $about_single_image = '';

        if ( empty( $content_details ) ) {
            return;
        }

        foreach ( $content_details as $content_detail ) :
            if( 'demo' == $about_content_type ) {
                for( $i=1; $i<=3; $i++ ) {
                    $about_multiple_image[$i] = get_template_directory_uri() . '/assets/uploads/about-0' . $i .'.jpg';
                }
                $about_single_image = get_template_directory_uri() . '/assets/uploads/about-01.jpg';
            }
            elseif ( 'custom' == $about_content_type ) {
                for( $i=1; $i<=3; $i++ ) {
                    $about_multiple_image[$i] = $options['about_custom_image_'.$i ];
                }
                $about_single_image = $options['about_custom_image_1' ];
            }
            else {

                $about_multiple_image = elead_pro_catch_that_image( $content_detail['excerpt']);
                if( 'multiple-image' == $about_image_type && ( ! empty ( $about_multiple_image ) ) ) :
                    array_unshift( $about_multiple_image, '' );
                    unset( $about_multiple_image[0] );
                endif;
                $about_single_image   = $content_detail['img_array'][0];
            }
        ?>
        <section id="about" class="col-2">
            <div class="wrapper page-section">
                <div class="row">
                    <div class="hentry about-header">
                    <?php if( ! empty( $content_detail['title'] ) || ! empty( $about_subtitle ) ) : ?>
                        <header class="entry-header">
                            <?php if( ! empty( $content_detail['title'] ) ) { ?>
                                <h2 class="entry-title"><?php echo esc_html( $content_detail['title'] ); ?></h2>
                            <?php } 
                            if ( ! empty( $about_subtitle ) ) : ?>
                                <p class="entry-title-desc"><?php echo esc_html( $about_subtitle ); ?></p>
                            <?php endif; ?>
                        </header><!-- .entry-header -->
                    <?php endif; ?>           
                    </div><!-- .hentry -->

                    <div class="hentry">
                        <div class="about-image-wrapper clear">
                            <?php if( 'multiple-image' == $about_image_type ) { 
                                for( $i=1; $i<=3; $i++ ) { 
                                    if ( !empty( $about_multiple_image[$i] ) ) { ?>
                                        <div class="image-wrap">
                                            <div class="featured-image" style="background-image:url('<?php echo esc_url( $about_multiple_image[$i] );  ?>')">
                                            </div><!-- .featured-image -->
                                        </div><!-- .image-wrap -->    
                                    <?php }                                
                                } 
                            } 
                            else { 
                                if ( !empty( $about_single_image ) ) { ?>
                                    <div class="image-wrap single-image">
                                        <div class="featured-image" style="background-image:url('<?php echo esc_url( $about_single_image ); ?>')">
                                        </div><!-- .featured-image -->
                                    </div><!-- .image-wrap -->
                                <?php }
                            } ?> 
                        </div><!-- .about-image-wrapper -->                        
                    </div><!-- .hentry -->

                    <div class="hentry about-content">
                        <div class="entry-content">
                            <?php if( ! empty( $content_detail['trim_excerpt'] ) ) : ?>
                                <p><?php echo wp_kses_post( $content_detail['trim_excerpt'] ); ?></p>
                            <?php endif;
                            if( ! empty( $readmore ) ) : ?>
                                <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>" class="btn btn-transparent"><?php echo esc_html( $readmore ); ?></a>
                            <?php endif; ?>
                        </div><!-- .entry-content -->
                    </div><!-- .hentry -->
                </div><!-- .row -->
            </div><!-- .wrapper -->
            <div class="page-decoration">
                <img src="<?php echo get_template_directory_uri() . '/assets/uploads/decoration.png'; ?>" alt="<?php esc_attr__( 'Decoration','elead-pro' ); ?>">
            </div>
        </section><!-- #hero-section -->
        <?php endforeach;
    }
endif;