<?php 
/**
 * Subscribe section
 *
 * This is the template for the content of subscribe section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_subscribe' ) ) :
    /**
    * Add subscribe section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_subscribe() {
        $options = elead_pro_get_theme_options();

        // Check if subscribe is enabled
        $enable_subscribe = apply_filters( 'elead_pro_section_status', true, 'subscribe_enable' );

        if ( true !== $enable_subscribe || ! class_exists( 'Jetpack' ) || ! Jetpack::is_module_active( 'subscriptions' ) ) {
            return false;
        }

        // Render subscribe section now.
        elead_pro_render_subscribe_section();
    }
endif;
add_action( 'elead_pro_add_testimonial_subscribe_hook', 'elead_pro_add_subscribe', 20 );

if ( ! function_exists( 'elead_pro_render_subscribe_section' ) ) :
    /**
    * Start subscribe section
    *
    * @return string subscribe content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_subscribe_section() {
        $options    = elead_pro_get_theme_options();
        $background = ! empty( $options['subscribe_image'] ) ? $options['subscribe_image'] : get_template_directory_uri() . '/assets/uploads/subscribe-bg.jpg';
        $subscribe_logo = ! empty( $options['subscribe_logo'] ) ? $options['subscribe_logo'] : get_template_directory_uri() . '/assets/uploads/subscribe-logo.png';
        $title      = ! empty( $options['subscribe_title'] ) ? $options['subscribe_title'] : '';
        $sub_title  = ! empty( $options['subscribe_sub_title'] ) ? $options['subscribe_sub_title'] : '';
        $btn_label  = ! empty( $options['subscribe_btn_label'] ) ? $options['subscribe_btn_label'] : esc_html__( 'Subscribe', 'elead-pro' );
        $message    = ! empty( $options['subscribe_success_message'] ) ? $options['subscribe_success_message'] : esc_html__( 'Success! An email was just sent to confirm your subscription. Please find the email now and click ( Confirm Follow ) to start subscribing.', 'elead-pro' );
        ?>
        <div class="hentry align-center">
            <div class="subscribe-bg" style="background-image:url('<?php echo esc_url( $background ); ?>')">
                <div class="blue-overlay"></div>
                <div class="logo-background">
                    <div class="subscribe-logo">
                        <img src="<?php echo esc_url( $subscribe_logo ); ?>" class="custom-logo" alt="<?php esc_attr_e( 'subscribe-logo','elead-pro' ); ?>">
                    </div><!-- .subscribe-logo -->
                </div><!-- logo-background -->                        
                <?php
                $subscription_shortcode = '[jetpack_subscription_form title="' . esc_html( $title ) . '" subscribe_text="' . esc_html( $sub_title ) . '" subscribe_button="' . esc_html( $btn_label ) . '" show_subscribers_total="0"]';
                echo do_shortcode( wp_kses_post( $subscription_shortcode ) );
                ?>
            </div><!-- .bg-image -->
        </div><!-- .hentry -->
    <?php }
endif;
